@@ -234,7 +234,7 @@ class WEngine:
 
     def upd_carrier(self, client_id, name=None, active=None,
                     wserver_id=None, status=None, inn=None,
-                    kpp=None, ex_id=None):
+                    kpp=None, ex_id=None, **kwargs):
         """
         Обновить компанию-перевозчика.
 
